package com.energy.manage.service.service.system.impl;

import com.energy.manage.common.enums.TypeRelationEnum;
import com.energy.manage.common.po.powerwordcriterion.PowerWordCriterionPO;
import com.energy.manage.common.po.system.SysOrganizationAuthPO;
import com.energy.manage.common.po.windrelation.WindRelationPO;
import com.energy.manage.service.domain.vo.cockpit.CompanyFieldTreeRoleVo;
import com.energy.manage.service.mappers.system.SysOrganizationAuthMapper;
import com.energy.manage.service.service.system.SysOrganizationAuthService;
import com.energy.manage.service.util.BeanMapUtils;
import com.energy.manage.service.util.TreeUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import tk.mybatis.mapper.entity.Example;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * 企业风场关系
 *
 * @author chy
 * @date 2024/5/21 09:36
 * @desc
 */
@Service
public class SysOrganizationAuthServiceImpl implements SysOrganizationAuthService {

    /**
     * 根据角色查询风场编号列表返回key
     */
    private final static String FILE_CODE_LIST_KEY = "fieldCodeList";

    @Autowired
    private SysOrganizationAuthMapper sysOrganizationAuthMapper;

    /**
     * 根据角色id获取风场编号列表
     *
     * @return
     */
    @Override
    public Map<String, List<SysOrganizationAuthPO>> queryCodeNunByRoleId(Integer roleId) {
        Map<String, List<SysOrganizationAuthPO>> returnMap = new HashMap<>();
        List<SysOrganizationAuthPO> authPoList = sysOrganizationAuthMapper.selectByRoleId(roleId);
        authPoList.parallelStream().filter(po -> po.getCodeType().equals(TypeRelationEnum.WIND_FIELD_NUMBER.getCode()))
                .collect(Collectors.toList());
        returnMap.put(FILE_CODE_LIST_KEY, authPoList);
        return returnMap;
    }

    @Override
    public boolean verifySysOrganizationAuthByType(String codeName, String type) {
        Example queryExample = new Example(SysOrganizationAuthPO.class);
        Example.Criteria criteria = queryExample.createCriteria();
        criteria.andEqualTo("codeNumber", codeName);
        criteria.andEqualTo("codeType", type);
        return sysOrganizationAuthMapper.selectCountByExample(queryExample) > 0 ? false : true;
    }

    @Override
    public List<Map<String, Object>> getSysOrganizationAuthTreeByRoleId(Integer roleId) {

        List<CompanyFieldTreeRoleVo> list =  sysOrganizationAuthMapper.selectSysOrganizationAuthTreeByRoleId(roleId);
        // 转化为Map集合
        List<Map<String, Object>> mapList = BeanMapUtils.listBeanToListMap(list);
        // 获取树形结构
        List<Map<String, Object>> java8ResultTree = TreeUtil.getJava8ResultTree(mapList);

        return java8ResultTree;
    }

    @Override
    public List<CompanyFieldTreeRoleVo> getSysOrganizationAuthListByRoleId(Integer roleId) {

        List<CompanyFieldTreeRoleVo> list =  sysOrganizationAuthMapper.selectSysOrganizationAuthListByRoleId(roleId);

        return list;
    }


}
